"""
:authors: ZhuravlevDmi
:license: Apache License, version 2.0, see LICENSE file
"""

from .classCSV import WorkCSV
from .extradition import Extradition
from .filterArgs import FilterArgs
from .minerArgs import MinerArgs
from .WorkExtradition import WorkExtradition

__author__ = "ZhuravlevDmi"
__version__ = "0.1.1"
__email__ = "Dima15129@gmail.com"
